.. _user:

==========
User guide
==========

.. toctree::
    :caption: Getting started
    :maxdepth: 1

    installation.rst

.. toctree::
    :caption: Usage
    :maxdepth: 3

    ../tutorials/index.rst
    ../examples/index.rst

.. toctree::
    :caption: Resources

    bibliography.rst
    applications.rst
    related_projects.rst
    License <https://github.com/pyxem/orix/blob/develop/LICENSE>
